/* $Header: /cvs/gnome/gIDE/src/gI_functions.h,v 1.4 2000/04/22 17:23:01 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 Steffen Kern
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GI_FUNCTIONS_H
#define GI_FUNCTIONS_H

/*
 * Prototypes for 'gI_functions.c'
 */

typedef struct _c_status
{
	glong curly_brackets;
	glong round_brackets;
	glong square_brackets;
	glong comment;
	glong hyph;
	glong dhyph;
} c_status;

glong c_parse_special(gchar* buf, glong cc, c_status* c_status);
glong init_cstatus(c_status* c_status);
void show_all_functions(void);

#endif

